@@ -13,5 +13,5 @@ class PrintDot(tf.keras.callbacks.Callback):
         This will run whenever the training loop finishes an epoch.
         """
         if epoch % 100 == 0:
-            print("")
-        print(".", end="")
+            print("", flush=True)
+        print(".", end="", flush=True)
